@@ -39,7 +39,7 @@ def download(url, method = "GET", params = None, body = None, headers = None, pr
     proxys = proxys or []
     if isinstance(url, unicode):
         url = url.encode('utf8')
-    url = urllib.quote(url, safe=";|/|?|:|@|&|=|+|$|,")
+    url = urllib.quote(url, safe=";|/|?|:|@|&|=|+|$|,|%")
     for k, v in params.iteritems():
         if isinstance(v, unicode):
             params[k] = v.encode('utf8')    
